Package: diversityArch
Type: Package
Title: Computes Diversity Indices with Archaeological Data
Version: 0.3.0
Authors@R: c(
    person(
      "Andreu", "Sansó",
      email = "andreu.sanso@uib.eu",
      role = c("aut", "cre")
    ),
    person(
      "Arnaud", "Barat",
      email = "abarat@iphes.cat",
      role = c("aut")
    ),
    person(
      "Jordi", "Rosell",
      email = "jordirosellardevol@gmail.com",
      role = c("aut")
    )
  )
Description: Companion package of Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2025), "Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
License: GPL-2
Imports: methods
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-04 16:28:32 UTC; HP
Author: Andreu Sansó [aut, cre],
  Arnaud Barat [aut],
  Jordi Rosell [aut]
Maintainer: Andreu Sansó <andreu.sanso@uib.eu>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-05-04 17:00:02 UTC
Built: R 4.5.2; ; 2026-05-04 21:49:51 UTC; unix
