Package: diversityArch
Type: Package
Title: Computes Diversity Indices for Archaeological Data
Version: 0.4.0
Authors@R: c(
    person(
      "Andreu", "Sansó",
      email = "andreu.sanso@uib.eu",
      role = c("aut", "cre")
    ),
    person(
      "Arnaud", "Barat",
      email = "abarat@iphes.cat",
      role = c("aut")
    ),
    person(
      "Jordi", "Rosell",
      email = "jordirosellardevol@gmail.com",
      role = c("aut")
    )
  )
Description: Companion package of Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>. It computes Diversity Indices, decomposes several of them and computes bootstrap confidence intervals.
License: GPL-2
Imports: methods
Encoding: UTF-8
LazyData: true
Suggests: testthat (>= 3.0.0)
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-06-13 09:51:24 UTC; UIB
Author: Andreu Sansó [aut, cre],
  Arnaud Barat [aut],
  Jordi Rosell [aut]
Maintainer: Andreu Sansó <andreu.sanso@uib.eu>
Depends: R (>= 3.5.0)
Repository: CRAN
Date/Publication: 2026-06-13 10:10:02 UTC
