importFrom("stats", "na.omit")
importFrom("methods", "is")
export("all_indices")
export("bs")
export("bs_dec")
export("bs_frag")
export("dec_equit")
export("dec_shannon")
export("dominance")
export("equitability")
export("evenness")
export("margalef")
export("menhinick")
export("shannon")
export("shannon_frag")
export("simpson_D")
export("simpson_E")
