test_that(
  "Decomposition of Shannon Entropy. Returns 0.17038",
  {
    expected <- 0.16768
    data(Qesem_s)
    actual <- dec_shannon(Qesem_s$HU, Qesem_s$Group)$within
    expect_equal(round(actual,5), round(expected,5))
  }
)
