#' @title Simpson's evenness index
#'
#' @description Computes Simpson's evenness index.
#'
#' @param x Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.
#'
#' @return Simpson's evenness index.
#'
#' @seealso \link{evenness}, \link{simpson_D}
#'
#' @references
#' Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
#'
#' @examples
#' data(Qesem_s)
#' simpson_E(Qesem_s$HU)
#'
#' @export
simpson_E <- function(x){
  return(1-simpson_D(x))
}
