test_that(
  "Shannon index with fragmentari data. Returns 0.92707",
  {
    expected <- 0.9269
    data(Qesem_s)
    data(Qesem_f)
    actual <- shannon_frag(Qesem_s$HU, Qesem_s$Group,
                           Qesem_f$HU, Qesem_f$Group)$between
    expect_equal(round(actual,5), round(expected,5))
  }
)
