% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dec_equit.R
\name{dec_equit}
\alias{dec_equit}
\title{Decomposition of the equitability index}
\usage{
dec_equit(x, groups)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.}

\item{groups}{Vector of dimension S of factors indicating the group of each species.}
}
\value{
\itemize{
  \item \code{equitability}: Equitability index.
  \item \code{within}: Within groups equitability.
  \item \code{between}: Between groups equitability.
}
}
\description{
Computes equitability and its decomposition
}
\examples{
data(Qesem_s)
dec_equit(Qesem_s$HU, Qesem_s$Group)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{dec_shannon}
}
