\name{Qesem_s}
\alias{Qesem_s}
\docType{data}
\title{Data used in the examples}
\description{Data frame with number of bones of different species and diferent levels in Qesem (Israel),
  and a factor related to the size of the animal. Data source: Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., (2024)}
\usage{data(Qesem_s)}
\value{Data frame with 15 observations and 7 levels.}
\source{Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024. Exploring the lack of articular ends at the Middle Pleistocene site of Qesem Cave, Israel. Journal of Human Evolution 189, 103509. doi:10.1016/j.jhevol.2024.103509}
\references{Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I., Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R., Gopher, A. & Rosell-Ardèvol, J., 2025. Quantifying Diversity through Entropy Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave.
    Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A., 2024. Exploring the lack of articular ends at the Middle Pleistocene site of Qesem Cave, Israel. Journal of Human Evolution 189, 103509. doi:10.1016/j.jhevol.2024.103509}
\author{Blasco, R., Rosell, J., Assaf, E., Barkai, R., Gopher, A.}
\examples{
data(Qesem_s)
names(Qesem_s)
# The following example replicates some of the results in
# Barat, A. Sansó, A. Arilla-Osuna, M. Blasco, R., Pérez-Fernández, I.,
# Cifuentes-Alcobenda, G. Llorente, R., Vivar-Ríos, D., Assaf, E. Barkai, R.,
# Gopher, A. & Rosell-Ardèvol, J., 2025. "Quantifying Diversity through Entropy
# Decomposition. Insights into Hominin Occupation and Carcass Processing at Qesem cave".
all_indices(Qesem_s$HU)
}
\keyword{Datasets}
