% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shannon.R
\name{shannon}
\alias{shannon}
\title{Shannon diversity index}
\usage{
shannon(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}
}
\value{
Shannon's diversity index (Entropy).
}
\description{
Computes Shannon's diversity index
}
\examples{
data(Qesem_s)
shannon(Qesem_s$HU)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\seealso{
\link{dec_shannon}, \link{equitability}
}
