% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/all_indices.R
\name{all_indices}
\alias{all_indices}
\title{Diversity indices}
\usage{
all_indices(x, groups = NULL, B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species (in this case the Margalef and Menhinick indices and bootstrap intervals are not computed). NA values are allowed.}

\item{groups}{Vector of dimension S of factors indicating the groups. If omitted, the decomposition of the indicators is not done.}

\item{B}{Number of bootstrap samples. The default value is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default value is 0.95.}
}
\value{
{No return value. It prints the value of all indicators}
}
\description{
Computes and prints all the diversity indices
}
\examples{
data(Qesem_s)
all_indices(Qesem_s$HU)
all_indices(Qesem_s$HU, Qesem_s$Group)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
}
