% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs_dec.R
\name{bs_dec}
\alias{bs_dec}
\title{Bootstrap estimates of the decomposed diversity indices}
\usage{
bs_dec(x, groups, ind = "shannon", B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{groups}{Vector of dimension S of factors indicating the groups of each species.}

\item{ind}{Index to be computed. The default value is "shannon". The other possible value is "equitability".}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{bt_low}: Lower limit of the confidence interval for "between groups".
  \item \code{bt_up}: Upper limit of the confidence interval for "between groups".
  \item \code{wt_low}: Lower limit of the confidence interval for "within groups".
  \item \code{bt_up}: Upper limit of the confidence interval for "within groups".
}
}
\description{
Computes bootstrap confidence intervals of the decomposed diversity indices
}
\examples{
data(Qesem_s)
bs_dec(Qesem_s$HU, Qesem_s$Group)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
