% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs.R
\name{bs}
\alias{bs}
\title{Bootstrap estimates of the diversity indices}
\usage{
bs(x, ind = "shannon", B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}

\item{ind}{Index to be computed. The default value is "shannon". Other possible values are: "simpson_E", "simpson_D", "menhinick", "margalef", "evenness", "equitability" and "dominance".}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{s}: Boostrap standard error.
  \item \code{low}: Lower limit of the confidence interval.
  \item \code{up}: Upper limit of the confidence interval.
}
}
\description{
Computes bootstrap standard error and confidence interval of the diversity indices
}
\examples{
data(Qesem_s)
bs(Qesem_s$HU)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
