% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bs.R
\name{bs}
\alias{bs}
\title{Bootstrap estimates of the diversity indices}
\usage{
bs(x, ind = "shannon", B = 1000, cl = 0.95)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed.}

\item{ind}{Index to be computed. The default value is "shannon". Other possible values are: "simpson_E", "simpson_D", "menhinick", "margalef", "evenness", "equitability" and "dominance".}

\item{B}{Number of bootstrap samples. The default is 1000.}

\item{cl}{Confidence level. A value between 0 and 1. The default is 0.95.}
}
\value{
\itemize{
  \item \code{s}: Boostrap standard error.
  \item \code{ci}: Confidence interval.
}
}
\description{
Computes bootstrap standard error and confidence interval of the diversity indices
}
\examples{
data(Qesem_s)
bs(Qesem_s$HU)

}
\references{
Arnaud Barat, Andreu Sansó, Maite Arilla-Osuna, Ruth Blasco, Iñaki Pérez-Fernández, Gabriel Cifuentes-Alcobenda, Rubén Llorente, Daniel Vivar-Ríos, Ella Assaf, Ran Barkai, Avi Gopher, & Jordi Rosell-Ardèvol (2026) <doi:10.1007/s10816-026-09802-3>.
}
\seealso{
\link{shannon}, \link{dec_shannon}, \link{dominance}, \link{equitability}, \link{evenness}, \link{margalef}, \link{menhinick}, \link{simpson_D}, \link{simpson_E}
}
