% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_x.R
\name{check_x}
\alias{check_x}
\title{Check input}
\usage{
check_x(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}
}
\value{
x without NA or 0 values
}
\description{
Checks if x is a proper input
}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\keyword{internal}
