% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_x.R
\name{check_x}
\alias{check_x}
\title{Check input}
\usage{
check_x(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species, or the distribution frequencies of species. NA values are allowed.}
}
\value{
x without NA or 0 values
}
\description{
Checks if x is a proper input
}
\keyword{internal}
