% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dominance.R
\name{dominance}
\alias{dominance}
\title{Dominance index}
\usage{
dominance(x)
}
\arguments{
\item{x}{Vector of dimension S (number of species) with the number of individuals observed in each species. NA values are allowed. 0 values are converted to NA.}
}
\value{
Dominance index (Modified Simpson's dominance index).
}
\description{
Modification of the Simpson's dominance index to be restricted between 0 and 1.
}
\examples{
data(Qesem_s)
dominance(Qesem_s$HU)

}
\references{
"Quantifying Diversity through Entropy Decomposition: Insights into Hominin Occupation and Carcass Processing at Qesem cave"
}
\seealso{
\link{simpson_D}
}
